@@ -221,10 +221,6 @@ by a previous glob pattern specified in the files associated with
 .IP \fBGREP_PATH\fR
 May be used to specify a file path to pattern files.  The file path is used by
 option \fB-f\fR to open a pattern file, when the pattern file does not exist.
-.IP \fBGREP_EDITOR\fR
-May be used to specify an editor command to invoke with CTRL-Y while using the
-query UI with option \fB-Q\fR.  When undefined, the command defined by
-\fBEDITOR\fR is invoked.
 .IP \fBGREP_COLOR\fR
 May be used to specify ANSI SGR parameters to highlight matches when option
 \fB--color\fR is used, e.g. 1;35;40 shows pattern matches in bold magenta text
@@ -321,7 +317,7 @@ if not the first match: a colon, same as \fB%[:]>\fR.
 .IP \fB%;\fR
 if not the first match: a semicolon, same as \fB%[;]>\fR.
 .IP \fB%|\fR
-if not the first match: a verical bar, same as \fB%[|]>\fR.
+if not the first match: a vertical bar, same as \fB%[|]>\fR.
 .IP \fB%[\fR\fIARG\fR\fB]S\fR
 if not the first match: \fIARG\fR and separator, see also \fB%$\fR.
 .IP \fB%s\fR
